package com.ruoyi.app.service.impl;

import com.ruoyi.app.domain.AppProvider;
import com.ruoyi.app.mapper.AppProviderMapper;
import com.ruoyi.app.service.IAppProviderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@Service
public class AppProviderServiceImpl implements IAppProviderService {
    @Autowired
    private AppProviderMapper appProviderMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param providerId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public AppProvider selectAppProviderById(String providerId) {
        return appProviderMapper.selectAppProviderById(providerId);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appProvider 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<AppProvider> selectAppProviderList(AppProvider appProvider) {
        return appProviderMapper.selectAppProviderList(appProvider);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param appProvider 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertAppProvider(AppProvider appProvider) {
        return appProviderMapper.insertAppProvider(appProvider);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param appProvider 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateAppProvider(AppProvider appProvider) {
        return appProviderMapper.updateAppProvider(appProvider);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param providerIds 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppProviderByIds(String[] providerIds) {
        return appProviderMapper.deleteAppProviderByIds(providerIds);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param providerId 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppProviderById(String providerId) {
        return appProviderMapper.deleteAppProviderById(providerId);
    }
}
